@@ -4,12 +4,12 @@
 import os
 import re
 import time
+from urllib.parse import urlencode
 from functools import partial
 
 import structlog
 
 from . import session, HTTPError
-from ..sortversion import sort_version_keys
 
 logger = structlog.get_logger(logger_name=__name__)
 
@@ -26,19 +26,23 @@ async def get_version(name, conf, **kwargs):
 async def get_version_real(name, conf, **kwargs):
   repo = conf.get('github')
   br = conf.get('branch')
+  path = conf.get('path')
   use_latest_release = conf.getboolean('use_latest_release', False)
   use_max_tag = conf.getboolean('use_max_tag', False)
   include_tags_pattern = conf.get("include_tags_pattern", "")
   ignored_tags = conf.get("ignored_tags", "").split()
-  sort_version_key = sort_version_keys[conf.get("sort_version_key", "parse_version")]
   if use_latest_release:
     url = GITHUB_LATEST_RELEASE % repo
   elif use_max_tag:
     url = GITHUB_MAX_TAG % repo
   else:
     url = GITHUB_URL % repo
+    parameters = {}
     if br:
-      url += '?sha=' + br
+      parameters['sha'] = br
+    if path:
+      parameters['path'] = path
+    url += '?' + urlencode(parameters)
   headers = {
     'Accept': 'application/vnd.github.quicksilver-preview+json',
     'User-Agent': 'lilydjwg/nvchecker',
@@ -58,7 +62,7 @@ async def get_version_real(name, conf, **kwargs):
     return await max_tag(partial(
       session.get, headers=headers, **kwargs),
       url, name, ignored_tags, include_tags_pattern,
-      sort_version_key,
+      max_page = conf.get("max_page", 1),
     )
 
   async with session.get(url, headers=headers, **kwargs) as res:
@@ -81,12 +85,12 @@ async def get_version_real(name, conf, **kwargs):
   return version
 
 async def max_tag(
-  getter, url, name,
-  ignored_tags, include_tags_pattern, sort_version_key,
+  getter, url, name, ignored_tags, include_tags_pattern, max_page,
 ):
   # paging is needed
+  tags = []
 
-  while True:
+  for _ in range(max_page):
     async with getter(url) as res:
       logger.debug('X-RateLimit-Remaining',
                     n=res.headers.get('X-RateLimit-Remaining'))
@@ -98,8 +102,7 @@ async def max_tag(
       data = [x for x in data
               if re.search(include_tags_pattern, x)]
     if data:
-      data.sort(key=sort_version_key)
-      return data[-1]
+      tags += data
     else:
       next_page_url = get_next_page_url(links)
       if not next_page_url:
@@ -107,10 +110,11 @@ async def max_tag(
       else:
         url = next_page_url
 
-  logger.error('No tag found in upstream repository.',
-                name=name,
-                include_tags_pattern=include_tags_pattern)
-  return
+  if not tags:
+    logger.error('No tag found in upstream repository.',
+                  name=name,
+                  include_tags_pattern=include_tags_pattern)
+  return tags
 
 def get_next_page_url(links):
   links = links.split(', ')
